ng-polymer-elements example

# ng-paper-elements example

Text input
Core input
Paper input

Numeric input
Paper slider

Booleans
Checkbox
Paper checkbox
Paper toggle button

Radio buttons
First Second Third
Paper radio buttons
Paper tabs
First Second Third

Some content goes here

Paper dialog is {{dialogOpened ? 'opened' : 'closed'}}
Paper toast is {{toastOpened ? 'opened' : 'closed'}}

### Polymer core-list

### AngularJS ng-repeat

item # {{item.itemNumber}}